@@ -69,6 +69,8 @@ class Task(BaseModel):
     def to_crewai_task(self,
                        agent: Agent,
                        tools: List[Any] = [],
+                       parallel: bool = False,
+                       context: List[CrewAITask] = [],
                        output_json: type[BaseModel] | None = None,
                        output_pydantic: type[BaseModel] | None = None,) -> 'CrewAITask':
         logger.info(f"Creating CrewAI Task {self.name}")
@@ -76,17 +78,18 @@ class Task(BaseModel):
                           expected_output=self.expected_output,
                           agent=agent,
                           tools=tools,
+                          async_execution=parallel,
+                          context=context,
                           output_json=output_json,
                           output_pydantic=output_pydantic)
 
-    # def __str__(self) -> str:
 
 class Role(BaseModel):
     name: str
     description: str  # The CrewAI's goal of the role
     agent_system_message: str  # The CrewAI's background 
     examples: List[Example] = []
-    tasks: List[Task] = []
+    tasks: Dict[str, Task] = {}
     human_input_mode: Literal["ALWAYS", "NEVER", "TERMINATE"] = "TERMINATE"
     autogen_code_execution_config: dict = {}
 
@@ -154,25 +157,28 @@ class Role(BaseModel):
     def get_crew_ai_tasks(self, 
                           agent: Agent, 
                           tools: List[Any] = [],  
+                          parallel: bool = False,
+                          context: List[CrewAITask] = [],
                           output_json: type[BaseModel] | None = None,
-                          output_pydantic: type[BaseModel] | None = None,) -> List[CrewAITask]:
-        # TODO Combine this in a single method with the one below
-        tasks = []
-        for task in self.tasks:
-            tasks.append(task.to_crewai_task(agent, tools, output_json, output_pydantic))
-        return tasks
+                          output_pydantic: type[BaseModel] | None = None,) -> Dict[str, CrewAITask]:
+        crewai_tasks = {}
+        for task_name, task in self.tasks.items():
+            crewai_tasks[task_name] = task.to_crewai_task(agent, tools, parallel, context, output_json, output_pydantic)
+        return crewai_tasks
         
     def get_crew_ai_task(self, 
                          name: str, 
                          agent: Agent, 
                          tools: List[Any] = [],
+                         parallel: bool = False,
+                         context: List[CrewAITask] = [],                         
                          output_json: type[BaseModel] | None = None,
                          output_pydantic: type[BaseModel] | None = None,) -> Optional[CrewAITask]:
         # TODO Combine this in a single method with the one above
-        for task in self.tasks:
-            if task.name == name:
-                return task.to_crewai_task(agent, tools, output_json, output_pydantic)
-        return None
+        task = self.tasks.get(name, None)
+        if task is not None:
+            return task.to_crewai_task(agent, tools, parallel, context, output_json, output_pydantic)
+        return task
 
     def to_autogen_agent(self, 
                          name:str, 
